@@ -2,7 +2,9 @@ package PGXN::Site;
 
 use 5.10.0;
 use utf8;
-our $VERSION = v0.23.0;
+use strict;
+use warnings;
+our $VERSION = v0.23.2;
 
 sub version_string {
     sprintf 'v%vd', $VERSION;
