@@ -2,6 +2,8 @@ package PGXN::Site::Controller;
 
 use 5.10.0;
 use utf8;
+use strict;
+use warnings;
 #use aliased 'PGXN::Site::Request';
 use Plack::Request;
 use Plack::Response;
@@ -11,7 +13,7 @@ use Encode;
 use WWW::PGXN;
 use List::MoreUtils qw(any);
 use namespace::autoclean;
-our $VERSION = v0.23.0;
+our $VERSION = v0.23.2;
 
 Template::Declare->init( dispatch_to => ['PGXN::Site::Templates'] );
 
