@@ -2,11 +2,13 @@ package PGXN::Site::Locale;
 
 use 5.10.0;
 use utf8;
+use strict;
+use warnings;
 use parent 'Locale::Maketext';
 use I18N::LangTags::Detect;
 use File::Spec;
 use Carp;
-our $VERSION = v0.23.0;
+our $VERSION = v0.23.2;
 
 # Allow unknown phrases to just pass-through.
 our %Lexicon = (
