@@ -2,11 +2,13 @@ package PGXN::Site::Router;
 
 use 5.10.0;
 use utf8;
+use strict;
+use warnings;
 use PGXN::Site::Controller;
 use Router::Resource;
 use Plack::Builder;
 use Plack::App::File;
-our $VERSION = v0.23.0;
+our $VERSION = v0.23.2;
 
 sub app {
     my $class = shift;
